package ztl.model;

import java.text.DateFormat;
import java.util.Locale;

public class Ticket
{
	private static final double COSTPERHOUR = 3.0;
	
	private Transit entry;
	private Transit exit;
	private double cost;
	
	public Ticket(Transit entry, Transit exit)
	{
		if (!entry.getPlate().equals(exit.getPlate()))
			throw new IllegalArgumentException("!entry.getPlate().equals(exit.getPlate())");
		if (entry.getDirection() != Direction.ENTRY || exit.getDirection() != Direction.EXIT)
			throw new IllegalArgumentException("entry.getDirection() != Direction.ENTRY || exit.getDirection() != Direction.EXIT");
		if (entry.getDate().compareTo(exit.getDate()) >= 0)
			throw new IllegalArgumentException("entry.getDate().compareTo(exit.getDate()) >= 0");
		
		this.entry = entry;
		this.exit = exit;
		
		long duration = Math.round((exit.getDate().getTime() - entry.getDate().getTime()) / 60000.0);
		this.cost = (COSTPERHOUR / 60) * duration;
	}
	
	public Transit getEntryTransit()
	{
		return entry;
	}
	
	public Transit getExitTransit()
	{
		return exit;
	}
	
	public String getPlate()
	{
		return getEntryTransit().getPlate();
	}
	
	public double getCost()
	{
		return cost;
	}
	
	@Override
	public String toString()
	{
		DateFormat dateTimeFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT, Locale.ITALY);
		StringBuilder sb = new StringBuilder();
		sb.append("Plate '");
		sb.append(getEntryTransit().getPlate());
		sb.append("' - Entry '");
		sb.append(getEntryTransit().getGateName());
		sb.append(" [");
		sb.append(dateTimeFormat.format(getEntryTransit().getDate()));
		sb.append("]' - Exit '");
		sb.append(getExitTransit().getGateName());
		sb.append(" [");
		sb.append(dateTimeFormat.format(getExitTransit().getDate()));
		sb.append("]'");
		sb.append(" Total Cost: ");
		sb.append(getCost());
		return sb.toString();
	}
}
