package ztl.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import ztl.model.Direction;
import ztl.model.Transit;

public class MyTransitReader implements TransitReader
{
	
	@Override
	public List<Transit> read(Reader reader) throws IOException, MalformedFileException
	{
		ArrayList<Transit> transits = new ArrayList<Transit>();
		DateFormat dateTimeFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT, Locale.ITALY);
		BufferedReader bufferedReader = new BufferedReader(reader);
		String line;
		try
		{
			while ((line = bufferedReader.readLine()) != null && !line.trim().isEmpty())
			{
				StringTokenizer tok = new StringTokenizer(line);
				String gate = tok.nextToken();
				Direction direction = getDirection(tok.nextToken());
				String plate = tok.nextToken();
				Date date = getDate(dateTimeFormat, tok.nextToken("\n").trim());

				Transit transit = new Transit(gate, direction, date, plate);
				transits.add(transit);
			}
		}
		catch (NoSuchElementException e)
		{
			throw new MalformedFileException(e);
		}
		return transits;
	}

	private Date getDate(DateFormat dateTimeFormat, String dateTime) throws MalformedFileException
	{
		try
		{
			return dateTimeFormat.parse(dateTime);
		}
		catch (ParseException e)
		{
			throw new MalformedFileException(e);
		}
	}

	private Direction getDirection(String value) throws MalformedFileException
	{
		if ("entrata".equals(value))
		{
			return Direction.ENTRY;
		}
		if ("uscita".equals(value))
		{
			return Direction.EXIT;
		}
		throw new MalformedFileException("Not a valid direction: " + value);
	}

}
